@@ -67,7 +67,7 @@ final class ExporterTest extends TestCase
         $obj->self        = $obj;
 
         $storage = new SplObjectStorage;
-        $storage->attach($obj2);
+        $storage->offsetSet($obj2);
 
         $resource = fopen('php://memory', 'r');
 
